@@ -41,6 +41,7 @@
     external_url: { oclass: 'object.item', type: 'external_url', protocol: 'http-get' },
     image: { oclass: 'object.item.imageItem', type: 'item' },
     imagePhoto: { oclass: 'object.item.imageItem.photo', type: 'item' },
+    imageLink: { oclass: 'object.item.imageItem', type: 'external_url', protocol: 'http-get' },
     audio: { oclass: 'object.item.audioItem', type: 'item' },
     audioBroadcast: { oclass: 'object.item.audioItem.audioBroadcast', type: 'external_url', protocol: 'http-get' },
     video: { oclass: 'object.item.videoItem', type: 'item' },
@@ -61,6 +62,10 @@
     "OggTheora",
   ];
   let resources = [];
+  let references = [];
+  let serverConfig = {
+    editSortKey: true,
+  };
   function addNewItem(modal, itemData) {
     const itemType = itemData.type;
     const item = itemData.item;
@@ -68,6 +73,7 @@
     const editTitle = modal.find('#editTitle');
     const editLocation = modal.find('#editLocation');
     const editClass = modal.find('#editClass');
+    const editSortKey = modal.find('#editSortKey');
     const editDesc = modal.find('#editDesc');
     const editMime = modal.find('#editMime');
     const editProtocol = modal.find('#editProtocol');
@@ -105,7 +111,7 @@
     editObjectType.prop('disabled', false);
     editObjectType.prop('readonly', false);
     editObjectType.val(itemType);
-    let hiddenFields = [editLmt, editLut];
+    let hiddenFields = [editLmt, editLut, editFlags];
     objectFlags.forEach((flag) => {
       hiddenFields.push(editFlagBox[flag]);
     });
@@ -114,11 +120,21 @@
     editClass.val(defaultClasses[itemType].oclass);
     modal.find('.modal-dialog').removeClass('modal-xl');
     $("#editCol").hide();
+    if (serverConfig.editSortKey) {
+      showFields([editSortKey]);
+    } else {
+      hideFields([editSortKey]);
+    }
     if (defaultClasses[itemType].type === 'container') {
       showFields([editObjectType, editTitle, editClass, editFlags, editFlagBox['Searchable']]);
       hideFields([editLocation, editDesc, editMime, editProtocol]);
     } else if (defaultClasses[itemType].type === 'item') {
-      showFields([editObjectType, editTitle, editLocation, editClass, editDesc, editMime, editFlags, editFlagBox['OggTheora']]);
+      var allowedFields = [editObjectType, editTitle, editLocation, editClass, editDesc, editMime];
+      if (!defaultClasses[itemType].oclass.startsWith('object.item.imageItem')) {
+        allowedFields.push(editFlags);
+        allowedFields.push(editFlagBox['OggTheora']);
+      }
+      showFields(allowedFields);
       hideFields([editProtocol]);
     } else if (defaultClasses[itemType].type === 'external_url') {
       editProtocol.val(defaultClasses[itemType].protocol);
@@ -129,6 +145,8 @@
       $("#editCol").show();
       const restable = modal.find('#resdata');
       restable.html('');
+      const reftable = modal.find('#refdata');
+      reftable.html('');
       const tfoot = $('<tfoot></tfoot>');
       const trow = $('<tr></tr>');
       const th1 = $('<th></th>');
@@ -223,6 +241,7 @@
 
   function reset(modal) {
     resources = [];
+    references = [];
     modal.find('#editObjectType').val('item');
     modal.find('#objectId').val('');
     modal.find('#addParentId').val('');
@@ -231,6 +250,7 @@
     modal.find('#editTitle').val('').prop('disabled', false);
     modal.find('#editLocation').val('').prop('disabled', false);
     modal.find('#editClass').val('').prop('disabled', false);
+    modal.find('#editSortKey').val('').prop('disabled', false);
     modal.find('#editDesc').val('').prop('disabled', false);
     modal.find('#editMime').val('').prop('disabled', false);
     modal.find('#editFlags').val('').prop('disabled', true);
@@ -245,6 +265,7 @@
     modal.find('#metadata').empty();
     modal.find('#auxdata').empty();
     modal.find('#resdata').empty();
+    modal.find('#refdata').empty();
     modal.find('#mediaimage').empty();
 
     hideDetails(modal);
@@ -332,20 +353,22 @@
 
   function loadItem(modal, itemData) {
     const item = itemData.item;
+    serverConfig = itemData.serverConfig;
     if (item) {
       if (item.image) {
         modal.find('#mediaimage').prop('src', item.image.value);
         modal.find('#mediaimage').show();
       }
       let obj_type = item.obj_type;
+      let obj_cls = item.obj_type;
       if (item.class.value !== 'object.item') {
         Object.getOwnPropertyNames(defaultClasses).forEach((cls) => {
-          if (item.class.value.startsWith(defaultClasses[cls].oclass)) {
-            obj_type = defaultClasses[cls].type;
+          if (item.class.value.startsWith(defaultClasses[cls].oclass) && obj_type === defaultClasses[cls].type) {
+            obj_cls = cls;
           }
         });
       }
-      modal.find('#editObjectType').val(obj_type);
+      modal.find('#editObjectType').val(obj_cls);
       modal.find('#editObjectType').prop('disabled', true);
       modal.find('#editObjectType').prop('readonly', true);
       modal.find('#editdObjectIdTxt').text(item.object_id).closest('.form-group').show();
@@ -353,11 +376,11 @@
 
       const metatable = modal.find('#metadata');
       const detailButton = modal.find('#detailbutton');
-      if (item.metadata && item.metadata.metadata.length) {
+      if (item.metadata && item.metadata.length) {
         detailButton.show();
         const tbody = makeDetailsHead(metatable, 'Metadata', '', itemData.onData);
-        for (let i = 0; i < item.metadata.metadata.length; i++) {
-          appendMetaItem(tbody, item.metadata.metadata[i].metaname, item.metadata.metadata[i].metavalue);
+        for (let i = 0; i < item.metadata.length; i++) {
+          appendMetaItem(tbody, item.metadata[i].metaname, item.metadata[i].metavalue);
         }
       }
       if (item.flags && item.flags.value) {
@@ -368,12 +391,12 @@
       }
 
       const auxtable = modal.find('#auxdata');
-      if (item.auxdata && item.auxdata.auxdata.length) {
+      if (item.auxdata && item.auxdata.length) {
         detailButton.show();
         auxtable.show();
         const tbody = makeDetailsHead(auxtable, 'Aux Data', '', itemData.onData);
-        for (let i = 0; i < item.auxdata.auxdata.length; i++) {
-          appendMetaItem(tbody, item.auxdata.auxdata[i].auxname, item.auxdata.auxdata[i].auxvalue);
+        for (let i = 0; i < item.auxdata.length; i++) {
+          appendMetaItem(tbody, item.auxdata[i].auxname, item.auxdata[i].auxvalue);
         }
         tbody.hide();
       } else {
@@ -381,17 +404,17 @@
       }
 
       const restable = modal.find('#resdata');
-      if (item.resources && item.resources.resources.length) {
+      if (item.resources && item.resources.length > 0) {
         detailButton.show();
         restable.show();
         let currentResource = { index: '???', properties: [] };
-        for (let i = 0; i < item.resources.resources.length; i++) {
-          if (item.resources.resources[i].resname === '----RESOURCE----') {
-            currentResource = { index: item.resources.resources[i].resvalue, properties: [] };
+        for (let i = 0; i < item.resources.length; i++) {
+          if (item.resources[i].resname === '----RESOURCE----') {
+            currentResource = { index: item.resources[i].resvalue, properties: [] };
             resources.push(currentResource);
           } else {
-            currentResource.properties.push(item.resources.resources[i].resname);
-            currentResource[item.resources.resources[i].resname] = [item.resources.resources[i].resvalue, item.resources.resources[i].rawvalue];
+            currentResource.properties.push(item.resources[i].resname);
+            currentResource[item.resources[i].resname] = [item.resources[i].resvalue, item.resources[i].rawvalue];
           }
         }
         resources.forEach((res, i) => {
@@ -426,6 +449,20 @@
         restable.hide();
       }
 
+      const reftable = modal.find('#refdata');
+      if (item.references && item.references.length > 0) {
+        detailButton.show();
+        reftable.show();
+        references = item.references;
+        const tbody = makeDetailsHead(reftable, 'References', `(${references.length})`, itemData.onData);
+        tbody.hide();
+        references.forEach((ref) => {
+          appendMetaItem(tbody, ref.title, ref.location);
+        });
+      } else {
+        reftable.hide();
+      }
+
       loadCdsObject(modal, item);
       switch (item.obj_type) {
         case 'item': {
@@ -468,6 +505,18 @@
       .prop('disabled', true)
       .closest('.form-group').show();
 
+    if (serverConfig.editSortKey) {
+      modal.find('#editSortKey')
+        .val(item.sortKey.value)
+        .prop('disabled', !item.sortKey.editable)
+        .closest('.form-group').show();
+    } else {
+      modal.find('#editSortKey')
+        .val(item.sortKey.value)
+        .prop('disabled', !item.sortKey.editable)
+        .closest('.form-group').hide();
+    }
+
     if ('last_modified' in item && item['last_modified'].value !== '') {
       modal.find('#editLmt')
         .val(item['last_modified'].value)
@@ -603,11 +652,16 @@
     ]);
   }
 
+  function getSortKey(editSortKey, editTitle) {
+    return (serverConfig.editSortKey || editSortKey.val() !== '') ? editSortKey.val() : editTitle.val();
+  }
+
   function saveItem(modal) {
     let item;
     const objectId = modal.find('#objectId');
     const editObjectType = modal.find('#editObjectType');
     const editTitle = modal.find('#editTitle');
+    const editSortKey = modal.find('#editSortKey');
     const editLocation = modal.find('#editLocation');
     const editDesc = modal.find('#editDesc');
     const editMime = modal.find('#editMime');
@@ -618,6 +672,7 @@
         item = {
           object_id: objectId.val(),
           title: encodeURIComponent(editTitle.val()),
+          sortKey: encodeURIComponent(getSortKey(editSortKey, editTitle)),
           description: encodeURIComponent(editDesc.val()),
           flags: readFlags(modal),
         };
@@ -628,6 +683,7 @@
         item = {
           object_id: objectId.val(),
           title: encodeURIComponent(editTitle.val()),
+          sortKey: encodeURIComponent(getSortKey(editSortKey, editTitle)),
           flags: readFlags(modal),
         };
         readResources(item);
@@ -637,6 +693,7 @@
         item = {
           object_id: objectId.val(),
           title: encodeURIComponent(editTitle.val()),
+          sortKey: encodeURIComponent(getSortKey(editSortKey, editTitle)),
           description: encodeURIComponent(editDesc.val()),
           location: encodeURIComponent(editLocation.val()),
           'mime-type': encodeURIComponent(editMime.val()),
@@ -655,6 +712,7 @@
     const parentId = modal.find('#addParentId');
     const editObjectType = modal.find('#editObjectType');
     const editClass = modal.find('#editClass');
+    const editSortKey = modal.find('#editSortKey');
     const editTitle = modal.find('#editTitle');
     const editLocation = modal.find('#editLocation');
     const editDesc = modal.find('#editDesc');
@@ -668,6 +726,7 @@
           obj_type: defaultClasses[editObjectType.val()].type,
           class: editClass.val(),
           title: encodeURIComponent(editTitle.val()),
+          sortKey: encodeURIComponent(getSortKey(editSortKey, editTitle)),
           location: encodeURIComponent(editLocation.val()),
           description: encodeURIComponent(editDesc.val()),
           flags: readFlags(modal),
@@ -681,6 +740,7 @@
           obj_type: defaultClasses[editObjectType.val()].type,
           class: editClass.val(),
           title: encodeURIComponent(editTitle.val()),
+          sortKey: encodeURIComponent(getSortKey(editSortKey, editTitle)),
           flags: readFlags(modal),
         };
         readResources(item);
@@ -692,6 +752,7 @@
           obj_type: defaultClasses[editObjectType.val()].type,
           class: editClass.val(),
           title: encodeURIComponent(editTitle.val()),
+          sortKey: encodeURIComponent(getSortKey(editSortKey, editTitle)),
           description: encodeURIComponent(editDesc.val()),
           location: encodeURIComponent(editLocation.val()),
           'mime-type': encodeURIComponent(editMime.val()),
@@ -772,5 +833,5 @@
       retval = this;
     }
     return retval;
-  }, $.fn.editmodal)
+  }, $.fn.editmodal);
 })(jQuery);
