@@ -4,7 +4,7 @@
 
     jquery.gerbera.trail.js - this file is part of Gerbera.
 
-    Copyright (C) 2016-2024 Gerbera Contributors
+    Copyright (C) 2016-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -68,13 +68,27 @@ $.widget('grb.trail', {
     buttons.addClass('grb-trail-buttons pull-right my-auto');
 
     if (config.enableAdd && config.onAdd) {
-      const addItemIcon = this.generateItemButton(item, {
-        title: 'Add Item',
-        class: 'grb-trail-add',
-        iconClass: 'fa-plus',
-        click: config.onAdd ? config.onAdd : noOp
-      });
-      addItemIcon.appendTo(buttons);
+      if (config.itemType === 'fs') {
+        // We're in filesystem view
+        const addItemIcon = this.generateItemButton(item, {
+          title: 'Add Items',
+          tooltip: 'Add folder and subfolders to database',
+          class: 'grb-trail-add',
+          iconClass: 'fa-plus',
+          click: config.onAdd ? config.onAdd : noOp
+        });
+        addItemIcon.appendTo(buttons);
+      } else {
+        // We're in database view
+        const addItemIcon = this.generateItemButton(item, {
+          title: 'Add Item',
+          tooltip: 'Add Container or Item to virtual layout',
+          class: 'grb-trail-add',
+          iconClass: 'fa-plus',
+          click: config.onAdd ? config.onAdd : noOp
+        });
+        addItemIcon.appendTo(buttons);
+      }
     }
 
     if (config.enableEdit && config.onEdit) {
@@ -87,17 +101,27 @@ $.widget('grb.trail', {
       editItemIcon.appendTo(buttons);
     }
 
-    let autoscanItemIcon;
+    if (config.enableRunScan && config.onRunScan) {
+      const autoscanItemIcon = this.generateItemButton(item, {
+        title: 'Scan Now',
+        tooltip: 'Run Autoscan Immediately',
+        class: 'grb-trail-run-autoscan',
+        iconClass: 'fa-spinner',
+        click: config.onRunScan ? config.onRunScan : noOp
+      });
+      autoscanItemIcon.appendTo(buttons);
+    }
     if (config.enableAddAutoscan && config.onAddAutoscan) {
-      autoscanItemIcon = this.generateItemButton(item, {
-        title: 'Add Autoscan Item',
+      const autoscanItemIcon = this.generateItemButton(item, {
+        title: 'Add Autoscan Directory',
+        tooltip: 'Configure folder as autoscan item',
         class: 'grb-trail-add-autoscan',
         iconClass: 'fa-history',
         click: config.onAddAutoscan ? config.onAddAutoscan : noOp
       });
       autoscanItemIcon.appendTo(buttons);
     } else if (config.enableEditAutoscan && config.onEditAutoscan) {
-      autoscanItemIcon = this.generateItemButton(item, {
+      const autoscanItemIcon = this.generateItemButton(item, {
         title: 'Edit Autoscan Item',
         class: 'grb-trail-edit-autoscan',
         iconClass: 'fa-history',
@@ -108,7 +132,8 @@ $.widget('grb.trail', {
 
     if (config.enableDelete && config.onDelete) {
       const deleteItemIcon = this.generateItemButton(item, {
-        title: 'Delete Item',
+        title: 'Delete Container',
+        tooltip: 'Delete container and items of container',
         class: 'grb-trail-delete',
         iconClass: 'fa-trash-o',
         click: config.onDelete ? config.onDelete : noOp
@@ -118,7 +143,8 @@ $.widget('grb.trail', {
 
     if (config.enableDeleteAll && config.onDeleteAll) {
       const deleteAllIcon = this.generateItemButton(item, {
-        title: 'Delete All',
+        title: 'Delete with References',
+        tooltip: 'Delete container, items and all references',
         class: 'grb-trail-delete-all',
         iconClass: 'fa-remove',
         click: config.onDeleteAll ? config.onDeleteAll : noOp
@@ -157,6 +183,7 @@ $.widget('grb.trail', {
     if (config.enableAddTweak && config.onAddTweak) {
       const tweakIcon = this.generateItemButton(item, {
         title: 'Tweak Directory',
+        tooltip: 'Set special import properties for folder',
         class: 'grb-trail-tweak-dir',
         iconClass: 'fa-address-card-o',
         click: config.onAddTweak ? config.onAddTweak : noOp
@@ -173,8 +200,8 @@ $.widget('grb.trail', {
 
   generateItemButton: function (item, config) {
     const button = $('<li>');
-    const link = $('<a>', {"title": config.title, "class": "grb-trail-button " + config.class, "href": "javascript:;"});
-    const icon = $('<i></i>', {"class": "fa " + config.iconClass });
+    const link = $('<a>', { "title": config.tooltip ? config.tooltip : config.title, "class": "grb-trail-button " + config.class, "href": "javascript:;" });
+    const icon = $('<i></i>', { "class": "fa " + config.iconClass });
     link.append(icon);
     link.append('<span> ' + config.title + '</span>');
     button.append(link);
